Stan Math Library: stan/math/prim/mat/meta/seq_view.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
seq_view.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::store_type< T >
struct | stan::math::store_type< double >
struct | stan::math::store_type< int >
struct | stan::math::pass_type< T >
struct | stan::math::pass_type< double >
struct | stan::math::pass_type< int >
class | stan::math::seq_view< T, S >
class | stan::math::seq_view< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > >
class | stan::math::seq_view< T, Eigen::Matrix< S, 1, Eigen::Dynamic > >
class | stan::math::seq_view< T, Eigen::Matrix< S, Eigen::Dynamic, Eigen::Dynamic > >
class | stan::math::seq_view< T, std::vector< S > >
class | stan::math::seq_view< T, std::vector< T > >
class | stan::math::seq_view< T, std::vector< std::vector< T > > >
class | stan::math::seq_view< double, std::vector< int > >

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.